"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Comment = void 0;
const request_1 = require("./request");
/**
 * 评论区
 */
class Comment {
    constructor(credential, oid, type) {
        this.oid = oid;
        this.type = type;
        this.credential = credential;
    }
    async add(message, oid, type) {
        oid = oid ?? this.oid;
        type = type ?? this.type;
        if (!oid || !type)
            throw "需要提供oid和type";
        let payload = {
            oid,
            message,
            type,
            plat: 1,
            ordering: "heat",
            jsonp: "jsonp",
            csrf: this.credential.csfr,
        };
        return request_1.Request.post("https://api.bilibili.com/x/v2/reply/add", payload, this.credential).then(res => { return res; });
    }
    async reply(root, parent, message, oid, type) {
        oid = oid ?? this.oid;
        type = type ?? this.type;
        if (!oid || !type)
            throw "需要提供oid和type";
        let payload = {
            oid,
            message,
            type,
            root,
            parent,
            plat: 1,
            ordering: "heat",
            jsonp: "jsonp",
            csrf: this.credential.csfr,
        };
        return request_1.Request.post("https://api.bilibili.com/x/v2/reply/add", payload, this.credential).then(res => { return res; });
    }
    async delete(reply_id, oid, type) {
        oid = oid ?? this.oid;
        type = type ?? this.type;
        if (!oid || !type)
            throw "需要提供oid和type";
        return request_1.Request.post("https://api.bilibili.com/x/v2/reply/del", {
            oid: oid,
            rpid: reply_id,
            type: type,
            jsonp: "jsonp",
            csrf: this.credential.csfr,
        }, this.credential);
    }
    async top(reply_id, action, oid, type) {
        oid = oid ?? this.oid;
        type = type ?? this.type;
        if (!oid || !type)
            throw "需要提供oid和type";
        return request_1.Request.post("https://api.bilibili.com/x/v2/reply/top", {
            oid,
            rpid: reply_id,
            type,
            action: action ? 1 : 0,
            jsonp: "jsonp",
            csrf: this.credential.csfr,
        }, this.credential);
    }
    async list(page_num = 0, sort = 1 /* like */, oid, type) {
        oid = oid ?? this.oid;
        type = type ?? this.type;
        if (!oid || !type)
            throw "需要提供oid和type";
        return request_1.Request.get("https://api.bilibili.com/x/v2/reply", {
            pn: page_num,
            type: type,
            oid: oid,
            sort: sort
        }, this.credential).then(res => {
            console.log(Object.keys(res));
            return res.data.data;
        });
    }
    async like(rpid, action = true, oid, type) {
        oid = oid ?? this.oid;
        type = type ?? this.type;
        if (!oid || !type)
            throw "需要提供oid和type";
        return request_1.Request.get("https://api.bilibili.com/x/v2/reply/action", {
            oid,
            type,
            rpid,
            action: action ? 1 : 0,
            ordering: "heat",
            jsonp: "jsonp",
        }, this.credential).then(res => { return res.code === 0; });
    }
    async hate(rpid, action = true, oid, type) {
        oid = oid ?? this.oid;
        type = type ?? this.type;
        if (!oid || !type)
            throw "需要提供oid和type";
        return request_1.Request.get("http://api.bilibili.com/x/v2/reply/hate", {
            oid,
            type,
            rpid,
            action: action ? 1 : 0,
            ordering: "heat",
            jsonp: "jsonp",
        }, this.credential).then(res => { return res.code === 0; });
    }
}
exports.Comment = Comment;
//# sourceMappingURL=comment.js.map